@@ -18,7 +18,8 @@ test_that("Cookies", {
   expect_equal(curl_fetch_memory(httpbin("cookies/set?foo=123&bar=456"), handle = h)$status, 200)
   expect_equal(jsonlite::fromJSON(rawToChar(curl_fetch_memory(httpbin("cookies"), handle = h)$content))$cookies$bar, "456")
   expect_equal(curl_fetch_memory(httpbin("cookies/delete?bar"), handle = h)$status, 200)
-  expect_equal(jsonlite::fromJSON(rawToChar(curl_fetch_memory(httpbin("cookies"), handle = h)$content))$cookies$bar, NULL)
+  if(curl::curl_version()$version == "7.62.0") Sys.sleep(1) #workaround for curl bug #3351
+  expect_null(jsonlite::fromJSON(rawToChar(curl_fetch_memory(httpbin("cookies"), handle = h)$content))$cookies$bar)
 })
 
 test_that("Keep-Alive", {
@@ -32,35 +33,6 @@ test_that("Keep-Alive", {
   handle_setopt(h, verbose=FALSE)
 })
 
-test_that("Compression and destroying connection", {
-  con <- curl(httpbin("deflate"), handle = h)
-  expect_equal(jsonlite::fromJSON(readLines(con))$deflate, TRUE)
-  expect_false(isOpen(con))
-  close(con) #destroy
-
-  expect_equal(jsonlite::fromJSON(rawToChar(curl_fetch_memory(httpbin("deflate"), handle = h)$content))$deflate, TRUE)
-
-  con <- curl(httpbin("gzip"), handle = h)
-  expect_equal(jsonlite::fromJSON(readLines(con))$gzipped, TRUE)
-  expect_false(isOpen(con))
-  close(con) #destroy
-
-  expect_equal(jsonlite::fromJSON(rawToChar(curl_fetch_memory(httpbin("gzip"), handle = h)$content))$gzipped, TRUE)
-})
-
-test_that("Connection interface", {
-  # note: jsonlite automatically destroys auto-opened connection
-  con <- curl(httpbin("get?test=blabla"), handle = h)
-  expect_equal(jsonlite::fromJSON(con)$args$test, "blabla")
-  con <- curl(httpbin("cookies"), handle = h)
-  expect_equal(jsonlite::fromJSON(con)$cookies$foo, "123")
-
-  # test error
-  con <- curl(httpbin("status/418"))
-  expect_error(readLines(con))
-  close(con) #destroy
-})
-
 test_that("Opening and closing a connection",{
   # Create connection
   con <- curl(httpbin("cookies"), handle = h)
